﻿"""
    Script for step 1 of the wizard
    This script list all available project, and offers to create a new one.
    If a project is selected, the designs of this project are displayed 
    (only HFSS 3D, HFSS-IE, Q3D and Maxwell 3D)
"""
global step1 
step1 = None


def ValidateProject(step,property):
    """
        called when a project is selected, it populates the available designs (existing or new ones)
    """
    #list the designs
    designs = step.Properties["ProjectDesign/Design"].Options
    designs.Clear()
    designs.Add("New HFSS Design")
    if step.Properties["ProjectDesign/Project"].Value !="New Project":
        Project = oDesktop.SetActiveProject(step.Properties["ProjectDesign/Project"].Value)
        DesignList = Project.GetDesigns()
        for Design in DesignList:
            if Design.GetDesignType()  == "HFSS":
                designs.Add(Design.GetName())
    step.Properties["ProjectDesign/Design"].Value = "New HFSS Design"
    PropCS = step.Properties["CoordinateSystem/CoordinateSystem"]
    PropCS.Options.Clear()
    PropCS.Options.Add("Global")
    PropCS.Value = "Global"
    # refresh display
    step.UserInterface.GetComponent("Properties").Refresh()


def ValidateDesign(step,property):
    """
        called when a design is selected, populates the CS menu
    """
    CSs= step.Properties["CoordinateSystem/CoordinateSystem"].Options
    CSs.Clear()
    if not property.Value == "New HFSS Design":
        oProject = oDesktop.SetActiveProject(step.Properties["ProjectDesign/Project"].Value)
        oDesign = oProject.SetActiveDesign(property.Value)
        oEditor = oDesign.SetActiveEditor("3D Modeler")
        CSList = oEditor.GetCoordinateSystems()
        for CS in CSList:
            CSs.Add(CS)
    else: 
        CSs.Add("Global")
    step.UserInterface.GetComponent("Properties").Refresh()


def RefreshChoice(step):
    """
        Called when page is refreshed (at start, or when clicking on back from next step)
    """
    global step1 
    step1 = step
    # Setup the "Update" button
    updateBtnSession = step.UserInterface.GetComponent("Button")
    updateBtnSession.AddButton("Refresh", "Refresh Lists", ButtonPositionType.Center)
    updateBtnSession.ButtonClicked += UpdateButtonClicked
    #don't refresh when back
    if ExtAPI.Extension.Attributes["back"]== "yes":
        return
    PopulateSelections(step)


def UpdateButtonClicked(sender, args):
    """
        This method is called when user clicks on button "Refresh"
    """
    global step1
    PopulateSelections(step1)


def PopulateSelections(step):
    """
        Method to populate the selection menus
    """
    #init Project list
    Projects = step.Properties["ProjectDesign/Project"]
    try:
        ProjectList = oDesktop.GetProjectList()
    except:
        ExtAPI.Log.WriteMessage("no oDesktop on init proj")
        #oDesktop is not available
        return
    Projects.Options.Clear()
    for Project in ProjectList:
        Projects.Options.Add(Project)
    Projects.Options.Add("New Project")
    ActiveProject = oDesktop.GetActiveProject()
    if ActiveProject is not None :
        Projects.Value = ActiveProject.GetName()
    else:
        Projects.Value = "New Project"

    #init design list
    Designs = step.Properties["ProjectDesign/Design"]
    designs = Designs.Options
    designs.Clear()
    designs.Add("New HFSS Design")
    Designs.Value = "New HFSS Design"
    if step.Properties["ProjectDesign/Project"].Value !="New Project":
        if ActiveProject.GetActiveDesign() !=None:
            ActiveDesign = ActiveProject.GetActiveDesign()
            DesignName = ActiveDesign.GetName()
        else:
            DesignName =""
        DesignList = ActiveProject.GetDesigns()
        for Design in DesignList:
            if Design.GetDesignType() == "HFSS":
                designs.Add(Design.GetName())
                if Design.GetName() == DesignName:
                    Designs.Value = DesignName

    #init CS list:
    CoordinateSystems = step.Properties["CoordinateSystem/CoordinateSystem"]
    CoordinateSystems.Options.Clear()
    if not step.Properties["ProjectDesign/Design"].Value == "New HFSS Design":
        if ActiveProject.GetActiveDesign() != None:
            Editor = ActiveDesign.SetActiveEditor("3D Modeler")
            CSs= Editor.GetCoordinateSystems()
            for CS in CSs:
                CoordinateSystems.Options.Add(CS)
    else : 
        CoordinateSystems.Options.Add("Global")
    CoordinateSystems.Value = "Global"

    properties = step.UserInterface.GetComponent("Properties")
    properties.UpdateData()
    properties.Refresh()

def back(step):
    """
        When clicking on back button, the populate selection is not called
        Not calling it allows us to keep the user choice for step 1
    """
    ExtAPI.Extension.Attributes["back"]= "yes" 
    pass

def next(step):
    """
        called when clicking on "next" button
    """
    ExtAPI.Extension.Attributes["back"]= "no"
    if step.Properties["ProjectDesign/Project"].Value !="New Project":
        Project = oDesktop.SetActiveProject(step.Properties["ProjectDesign/Project"].Value)
    if not step.Properties["ProjectDesign/Design"].Value.Contains("New"):
        Project.SetActiveDesign(step.Properties["ProjectDesign/Design"].Value)